/*
 Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */


#include <editor/id.h>
#include <filter/roles.h>
#include <filter/string.h>
#include <filter/usfm.h>
#include <filter/date.h>
#include <webserver/request.h>
#include <ipc/focus.h>
#include <database/ipc.h>
#include <access/bible.h>


std::string editor_id_url ()
{
  return "editor/id";
}


bool editor_id_acl (Webserver_Request& webserver_request)
{
  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
    return true;
  auto [ read, write ] = access_bible::any (webserver_request);
  return read;
}


std::string editor_id (Webserver_Request& webserver_request)
{
  // Update the timestamp indicating that the Bible editor is alive.
  webserver_request.database_config_user()->setLiveBibleEditor (filter::date::seconds_since_epoch ());

  
  std::string bible = webserver_request.query ["bible"];
  int book = filter::strings::convert_to_int (webserver_request.query ["book"]);
  int chapter = filter::strings::convert_to_int (webserver_request.query ["chapter"]);
  int id = webserver_request.database_bibles()->get_chapter_id (bible, book, chapter);
  return filter::strings::convert_to_string (id);
}
